@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import sys
 import typing
 from collections import abc
@@ -17,7 +19,6 @@ from typing_extensions import Annotated, Self, get_args, get_origin
 from strawberry.exceptions.not_a_strawberry_enum import NotAStrawberryEnumError
 from strawberry.private import is_private
 
-
 try:
     from typing import ForwardRef
 except ImportError:  # pragma: no cover
@@ -27,19 +28,14 @@ except ImportError:  # pragma: no cover
 from strawberry.custom_scalar import ScalarDefinition
 from strawberry.enum import EnumDefinition
 from strawberry.lazy_type import LazyType, StrawberryLazyReference
-from strawberry.type import (
-    StrawberryList,
-    StrawberryOptional,
-    StrawberryType,
-    StrawberryTypeVar,
-)
+from strawberry.type import StrawberryList, StrawberryOptional, StrawberryTypeVar
 from strawberry.types.types import TypeDefinition
 from strawberry.unset import UNSET
 from strawberry.utils.typing import is_generic, is_list, is_type_var, is_union
 
-
 if TYPE_CHECKING:
     from strawberry.field import StrawberryField
+    from strawberry.type import StrawberryType
     from strawberry.union import StrawberryUnion
 
 
@@ -70,7 +66,7 @@ class StrawberryAnnotation:
     @staticmethod
     def from_annotation(
         annotation: object, namespace: Optional[Dict] = None
-    ) -> Optional["StrawberryAnnotation"]:
+    ) -> Optional[StrawberryAnnotation]:
         if annotation is None:
             return None
 
@@ -163,7 +159,7 @@ class StrawberryAnnotation:
         # ... raise NotImplementedError(f"Unknown type {evaled_type}")
         return evaled_type
 
-    def set_namespace_from_field(self, field: "StrawberryField"):
+    def set_namespace_from_field(self, field: StrawberryField):
         module = sys.modules[field.origin.__module__]
         self.namespace = module.__dict__
 
@@ -193,7 +189,7 @@ class StrawberryAnnotation:
         types = evaled_type.__args__
         non_optional_types = tuple(
             filter(
-                lambda x: x is not type(None) and x is not type(UNSET),  # noqa: E721
+                lambda x: x is not type(None) and x is not type(UNSET),
                 types,
             )
         )
@@ -215,7 +211,7 @@ class StrawberryAnnotation:
     def create_type_var(self, evaled_type: TypeVar) -> StrawberryTypeVar:
         return StrawberryTypeVar(evaled_type)
 
-    def create_union(self, evaled_type) -> "StrawberryUnion":
+    def create_union(self, evaled_type) -> StrawberryUnion:
         # Prevent import cycles
         from strawberry.union import StrawberryUnion
 
@@ -264,7 +260,7 @@ class StrawberryAnnotation:
         types = annotation.__args__
 
         # A Union to be optional needs to have at least one None type
-        return any(x is type(None) for x in types)  # noqa: E721
+        return any(x is type(None) for x in types)
 
     @classmethod
     def _is_list(cls, annotation: Any) -> bool:
@@ -272,11 +268,7 @@ class StrawberryAnnotation:
 
         annotation_origin = getattr(annotation, "__origin__", None)
 
-        return (
-            annotation_origin == list
-            or annotation_origin == tuple
-            or annotation_origin is abc.Sequence
-        )
+        return (annotation_origin in (list, tuple)) or annotation_origin is abc.Sequence
 
     @classmethod
     def _is_strawberry_type(cls, evaled_type: Any) -> bool:
@@ -347,5 +339,4 @@ def _is_input_type(type_: Any) -> bool:
 
 
 def _is_object_type(type_: Any) -> bool:
-    # isinstance(type_, StrawberryObjectType)  # noqa: E800
     return hasattr(type_, "_type_definition")
