@@ -1,11 +1,15 @@
-from typing import Optional, Type
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional, Type
 
 from strawberry.utils.cached_property import cached_property
 
 from .exception import StrawberryException
-from .exception_source import ExceptionSource
 from .utils.source_finder import SourceFinder
 
+if TYPE_CHECKING:
+    from .exception_source import ExceptionSource
+
 
 class MissingFieldAnnotationError(StrawberryException):
     def __init__(self, field_name: str, cls: Type):
