@@ -1,11 +1,14 @@
-from typing import List, Type
+from __future__ import annotations
 
-from graphql import ASTValidationRule
+from typing import TYPE_CHECKING, Iterator, List, Type
 
-from strawberry.extensions.base_extension import Extension
+from strawberry.extensions.base_extension import SchemaExtension
+
+if TYPE_CHECKING:
+    from graphql import ASTValidationRule
 
 
-class AddValidationRules(Extension):
+class AddValidationRules(SchemaExtension):
     """
     Add graphql-core validation rules
 
@@ -38,7 +41,8 @@ class AddValidationRules(Extension):
     def __init__(self, validation_rules: List[Type[ASTValidationRule]]):
         self.validation_rules = validation_rules
 
-    def on_request_start(self) -> None:
+    def on_operation(self) -> Iterator[None]:
         self.execution_context.validation_rules = (
             self.execution_context.validation_rules + tuple(self.validation_rules)
         )
+        yield
