@@ -2,9 +2,9 @@ import importlib
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
-    from .apollo import ApolloTracingExtension, ApolloTracingExtensionSync  # noqa
-    from .datadog import DatadogTracingExtension, DatadogTracingExtensionSync  # noqa
-    from .opentelemetry import (  # noqa
+    from .apollo import ApolloTracingExtension, ApolloTracingExtensionSync
+    from .datadog import DatadogTracingExtension, DatadogTracingExtensionSync
+    from .opentelemetry import (
         OpenTelemetryExtension,
         OpenTelemetryExtensionSync,
     )
