@@ -1,17 +1,15 @@
+from __future__ import annotations
+
 import json
 import warnings
-from typing import Any, Dict, Optional, Type, Union
-from typing_extensions import Literal
+from typing import TYPE_CHECKING, Any, Dict, Optional, Type, Union
 
 from sanic.exceptions import NotFound, SanicException, ServerError
-from sanic.request import Request
 from sanic.response import HTTPResponse, html
 from sanic.views import HTTPMethodView
 from strawberry.exceptions import MissingQueryError
 from strawberry.file_uploads.utils import replace_placeholders_with_files
 from strawberry.http import (
-    GraphQLHTTPResponse,
-    GraphQLRequestData,
     parse_query_params,
     parse_request_data,
     process_result,
@@ -19,13 +17,19 @@ from strawberry.http import (
 from strawberry.http.temporal_response import TemporalResponse
 from strawberry.sanic.graphiql import should_render_graphiql
 from strawberry.sanic.utils import convert_request_to_files_dict
-from strawberry.schema import BaseSchema
 from strawberry.schema.exceptions import InvalidOperationTypeError
-from strawberry.types import ExecutionResult
 from strawberry.types.graphql import OperationType
 from strawberry.utils.graphiql import get_graphiql_html
 
-from .context import StrawberrySanicContext
+if TYPE_CHECKING:
+    from typing_extensions import Literal
+
+    from sanic.request import Request
+    from strawberry.http import GraphQLHTTPResponse, GraphQLRequestData
+    from strawberry.schema import BaseSchema
+    from strawberry.types import ExecutionResult
+
+    from .context import StrawberrySanicContext
 
 
 class GraphQLView(HTTPMethodView):
@@ -107,12 +111,7 @@ class GraphQLView(HTTPMethodView):
                     "Unable to parse request body as JSON", status_code=400
                 )
 
-            try:
-                request_data = parse_request_data(data)
-            except MissingQueryError:
-                raise ServerError(
-                    "No GraphQL query found in the request", status_code=400
-                )
+            request_data = parse_request_data(data)
 
             return await self.execute_request(
                 request=request, request_data=request_data, method="GET"
@@ -187,6 +186,8 @@ class GraphQLView(HTTPMethodView):
             raise ServerError(
                 e.as_http_error_reason(method=method), status_code=400
             ) from e
+        except MissingQueryError:
+            raise ServerError("No GraphQL query found in the request", status_code=400)
 
         response_data = await self.process_result(request, result)
 
@@ -198,12 +199,7 @@ class GraphQLView(HTTPMethodView):
         except json.JSONDecodeError:
             raise ServerError("Unable to parse request body as JSON", status_code=400)
 
-        try:
-            request_data = parse_request_data(data)
-        except MissingQueryError:
-            raise ServerError("No GraphQL query found in the request", status_code=400)
-
-        return request_data
+        return parse_request_data(data)
 
     def parse_request(self, request: Request) -> Dict[str, Any]:
         content_type = request.content_type or ""
