@@ -2,7 +2,9 @@ from __future__ import annotations
 
 import dataclasses
 import sys
+from functools import partial, reduce
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Dict,
@@ -23,49 +25,60 @@ from graphql import (
     GraphQLField,
     GraphQLInputField,
     GraphQLInputObjectType,
-    GraphQLInputType,
     GraphQLInterfaceType,
     GraphQLList,
     GraphQLNonNull,
-    GraphQLNullableType,
     GraphQLObjectType,
-    GraphQLOutputType,
-    GraphQLResolveInfo,
-    GraphQLScalarType,
     GraphQLUnionType,
     Undefined,
-    ValueNode,
 )
 from graphql.language.directive_locations import DirectiveLocation
 
 from strawberry.annotation import StrawberryAnnotation
 from strawberry.arguments import StrawberryArgument, convert_arguments
-from strawberry.custom_scalar import ScalarDefinition, ScalarWrapper
-from strawberry.directive import StrawberryDirective
-from strawberry.enum import EnumDefinition, EnumValue
+from strawberry.custom_scalar import ScalarWrapper
+from strawberry.enum import EnumDefinition
 from strawberry.exceptions import (
     DuplicatedTypeName,
     InvalidTypeInputForUnion,
+    InvalidUnionTypeError,
     MissingTypesForGenericError,
     ScalarAlreadyRegisteredError,
     UnresolvedFieldTypeError,
 )
-from strawberry.field import UNRESOLVED, StrawberryField
+from strawberry.field import UNRESOLVED
 from strawberry.lazy_type import LazyType
 from strawberry.private import is_private
-from strawberry.schema.config import StrawberryConfig
 from strawberry.schema.types.scalar import _make_scalar_type
-from strawberry.schema_directive import StrawberrySchemaDirective
-from strawberry.type import StrawberryList, StrawberryOptional, StrawberryType
+from strawberry.type import StrawberryList, StrawberryOptional
 from strawberry.types.info import Info
 from strawberry.types.types import TypeDefinition
 from strawberry.union import StrawberryUnion
 from strawberry.unset import UNSET
 from strawberry.utils.await_maybe import await_maybe
 
+from ..extensions.field_extension import build_field_extension_resolvers
 from . import compat
 from .types.concrete_type import ConcreteType
 
+if TYPE_CHECKING:
+    from graphql import (
+        GraphQLInputType,
+        GraphQLNullableType,
+        GraphQLOutputType,
+        GraphQLResolveInfo,
+        GraphQLScalarType,
+        ValueNode,
+    )
+
+    from strawberry.custom_scalar import ScalarDefinition
+    from strawberry.directive import StrawberryDirective
+    from strawberry.enum import EnumValue
+    from strawberry.field import StrawberryField
+    from strawberry.schema.config import StrawberryConfig
+    from strawberry.schema_directive import StrawberrySchemaDirective
+    from strawberry.type import StrawberryType
+
 
 # graphql-core expects a resolver for an Enum type to return
 # the enum's *value* (not its name or an instance of the enum). We have to
@@ -106,7 +119,9 @@ class GraphQLCoreConverter:
         self.scalar_registry = scalar_registry
 
     def from_argument(self, argument: StrawberryArgument) -> GraphQLArgument:
-        argument_type = cast(GraphQLInputType, self.from_maybe_optional(argument.type))
+        argument_type = cast(
+            "GraphQLInputType", self.from_maybe_optional(argument.type)
+        )
         default_value = Undefined if argument.default is UNSET else argument.default
 
         return GraphQLArgument(
@@ -179,7 +194,7 @@ class GraphQLCoreConverter:
 
     def from_schema_directive(self, cls: Type) -> GraphQLDirective:
         strawberry_directive = cast(
-            StrawberrySchemaDirective, cls.__strawberry_directive__
+            "StrawberrySchemaDirective", cls.__strawberry_directive__
         )
         module = sys.modules[cls.__module__]
 
@@ -216,7 +231,7 @@ class GraphQLCoreConverter:
         )
 
     def from_field(self, field: StrawberryField) -> GraphQLField:
-        field_type = cast(GraphQLOutputType, self.from_maybe_optional(field.type))
+        field_type = cast("GraphQLOutputType", self.from_maybe_optional(field.type))
 
         resolver = self.from_resolver(field)
         subscribe = None
@@ -243,7 +258,7 @@ class GraphQLCoreConverter:
         )
 
     def from_input_field(self, field: StrawberryField) -> GraphQLInputField:
-        field_type = cast(GraphQLInputType, self.from_maybe_optional(field.type))
+        field_type = cast("GraphQLInputType", self.from_maybe_optional(field.type))
         default_value: object
 
         if field.default_value is UNSET or field.default_value is dataclasses.MISSING:
@@ -265,7 +280,7 @@ class GraphQLCoreConverter:
 
     @staticmethod
     def _get_thunk_mapping(
-        fields: List[StrawberryField],
+        type_definition: TypeDefinition,
         name_converter: Callable[[StrawberryField], str],
         field_converter: Callable[[StrawberryField], FieldType],
     ) -> Dict[str, FieldType]:
@@ -282,19 +297,20 @@ class GraphQLCoreConverter:
         """
         thunk_mapping = {}
 
-        for f in fields:
-            if f.type is UNRESOLVED:
-                raise UnresolvedFieldTypeError(f.name)
+        for field in type_definition.fields:
+            if field.type is UNRESOLVED:
+                raise UnresolvedFieldTypeError(type_definition, field)
+
+            if not is_private(field.type):
+                thunk_mapping[name_converter(field)] = field_converter(field)
 
-            if not is_private(f.type):
-                thunk_mapping[name_converter(f)] = field_converter(f)
         return thunk_mapping
 
     def get_graphql_fields(
         self, type_definition: TypeDefinition
     ) -> Dict[str, GraphQLField]:
         return self._get_thunk_mapping(
-            fields=type_definition.fields,
+            type_definition=type_definition,
             name_converter=self.config.name_converter.from_field,
             field_converter=self.from_field,
         )
@@ -303,7 +319,7 @@ class GraphQLCoreConverter:
         self, type_definition: TypeDefinition
     ) -> Dict[str, GraphQLInputField]:
         return self._get_thunk_mapping(
-            fields=type_definition.fields,
+            type_definition=type_definition,
             name_converter=self.config.name_converter.from_field,
             field_converter=self.from_input_field,
         )
@@ -511,17 +527,37 @@ class GraphQLCoreConverter:
                 _source, info=info, args=field_args, kwargs=field_kwargs
             )
 
+        def wrap_field_extensions() -> Callable[..., Any]:
+            """Wrap the provided field resolver with the middleware."""
+
+            if not field.extensions:
+                return _get_result
+
+            for extension in field.extensions:
+                extension.apply(field)
+
+            extension_functions = build_field_extension_resolvers(field)
+            return reduce(
+                lambda chained_fns, next_fn: partial(next_fn, chained_fns),
+                extension_functions,
+                _get_result,
+            )
+
+        _get_result_with_extensions = wrap_field_extensions()
+
         def _resolver(_source: Any, info: GraphQLResolveInfo, **kwargs):
             strawberry_info = _strawberry_info_from_graphql(info)
             _check_permissions(_source, strawberry_info, kwargs)
 
-            return _get_result(_source, strawberry_info, **kwargs)
+            return _get_result_with_extensions(_source, strawberry_info, **kwargs)
 
         async def _async_resolver(_source: Any, info: GraphQLResolveInfo, **kwargs):
             strawberry_info = _strawberry_info_from_graphql(info)
             await _check_permissions_async(_source, strawberry_info, kwargs)
 
-            return await await_maybe(_get_result(_source, strawberry_info, **kwargs))
+            return await await_maybe(
+                _get_result_with_extensions(_source, strawberry_info, **kwargs)
+            )
 
         if field.is_async:
             _async_resolver._is_default = not field.base_resolver  # type: ignore
@@ -556,11 +592,18 @@ class GraphQLCoreConverter:
                 definition=scalar_definition, implementation=implementation
             )
         else:
-            if self.type_map[scalar_name].definition != scalar_definition:
-                raise ScalarAlreadyRegisteredError(scalar_name)
+            other_definition = self.type_map[scalar_name].definition
+
+            # TODO: the other definition might not be a scalar, we should
+            # handle this case better, since right now we assume it is a scalar
+
+            if other_definition != scalar_definition:
+                other_definition = cast("ScalarDefinition", other_definition)
+
+                raise ScalarAlreadyRegisteredError(scalar_definition, other_definition)
 
             implementation = cast(
-                GraphQLScalarType, self.type_map[scalar_name].implementation
+                "GraphQLScalarType", self.type_map[scalar_name].implementation
             )
 
         return implementation
@@ -611,6 +654,13 @@ class GraphQLCoreConverter:
     def from_union(self, union: StrawberryUnion) -> GraphQLUnionType:
         union_name = self.config.name_converter.from_type(union)
 
+        for type_ in union.types:
+            # This check also occurs in the Annotation resolving, but because of
+            # TypeVars, Annotations, LazyTypes, etc it can't perfectly detect issues at
+            # that stage
+            if not StrawberryUnion.is_valid_union_type(type_):
+                raise InvalidUnionTypeError(union_name, type_)
+
         # Don't reevaluate known types
         if union_name in self.type_map:
             graphql_union = self.type_map[union_name].implementation
@@ -699,8 +749,50 @@ class GraphQLCoreConverter:
             and isinstance(cached_type.definition, TypeDefinition)
             and cached_type.definition.concrete_of is not None
             and cached_type.definition.concrete_of == type_definition.concrete_of
+            and (
+                cached_type.definition.type_var_map.keys()
+                == type_definition.type_var_map.keys()
+            )
         ):
-            if cached_type.definition.type_var_map == type_definition.type_var_map:
+            # manually compare type_var_maps while resolving any lazy types
+            # so that they're considered equal to the actual types they're referencing
+            equal = True
+            for type_var, type1 in cached_type.definition.type_var_map.items():
+                type2 = type_definition.type_var_map[type_var]
+                # both lazy types are always resolved because two different lazy types
+                # may be referencing the same actual type
+                if isinstance(type1, LazyType):
+                    type1 = type1.resolve_type()
+                elif isinstance(type1, StrawberryOptional) and isinstance(
+                    type1.of_type, LazyType
+                ):
+                    type1.of_type = type1.of_type.resolve_type()
+
+                if isinstance(type2, LazyType):
+                    type2 = type2.resolve_type()
+                elif isinstance(type2, StrawberryOptional) and isinstance(
+                    type2.of_type, LazyType
+                ):
+                    type2.of_type = type2.of_type.resolve_type()
+
+                if type1 != type2:
+                    equal = False
+                    break
+            if equal:
                 return
 
-        raise DuplicatedTypeName(name)
+        if isinstance(type_definition, TypeDefinition):
+            first_origin = type_definition.origin
+        elif isinstance(type_definition, EnumDefinition):
+            first_origin = type_definition.wrapped_cls
+        else:
+            first_origin = None
+
+        if isinstance(cached_type.definition, TypeDefinition):
+            second_origin = cached_type.definition.origin
+        elif isinstance(cached_type.definition, EnumDefinition):
+            second_origin = cached_type.definition.wrapped_cls
+        else:
+            second_origin = None
+
+        raise DuplicatedTypeName(first_origin, second_origin, name)
